/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.image.internal.upgrade.v1_0_0;

import com.liferay.document.library.kernel.store.Store;
import com.liferay.petra.string.StringPool;
import com.liferay.portal.kernel.dao.orm.ActionableDynamicQuery;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.model.CompanyConstants;
import com.liferay.portal.kernel.model.Image;
import com.liferay.portal.kernel.service.ImageLocalService;
import com.liferay.portal.kernel.upgrade.UpgradeProcess;
import com.liferay.portlet.documentlibrary.store.StoreFactory;

import java.io.InputStream;

/**
 * @author Adolfo Pérez
 */
public class ImageStorageUpgradeProcess extends UpgradeProcess {

	public ImageStorageUpgradeProcess(
		ImageLocalService imageLocalService, StoreFactory storeFactory) {

		_imageLocalService = imageLocalService;
		_storeFactory = storeFactory;
	}

	@Override
	protected void doUpgrade() throws PortalException {
		Store store = _storeFactory.getStore();

		ActionableDynamicQuery actionableDynamicQuery =
			_imageLocalService.getActionableDynamicQuery();

		actionableDynamicQuery.setPerformActionMethod(
			(Image image) -> {
				String fileName = _getFileName(image);

				if (!store.hasFile(
						CompanyConstants.SYSTEM, _REPOSITORY_ID, fileName,
						StringPool.BLANK)) {

					return;
				}

				try (InputStream inputStream = store.getFileAsStream(
						CompanyConstants.SYSTEM, _REPOSITORY_ID, fileName,
						StringPool.BLANK)) {

					store.addFile(
						image.getCompanyId(), _REPOSITORY_ID, fileName,
						Store.VERSION_DEFAULT, inputStream);

					store.deleteFile(
						CompanyConstants.SYSTEM, _REPOSITORY_ID, fileName,
						Store.VERSION_DEFAULT);
				}
				catch (Exception exception) {
					_log.error(exception);
				}
			});

		actionableDynamicQuery.performActions();
	}

	private String _getFileName(Image image) {
		return image.getImageId() + StringPool.PERIOD + image.getType();
	}

	private static final long _REPOSITORY_ID = 0;

	private static final Log _log = LogFactoryUtil.getLog(
		ImageStorageUpgradeProcess.class);

	private final ImageLocalService _imageLocalService;
	private final StoreFactory _storeFactory;

}